#######################################################
#### Supplementary R code template for:            ####
#### Braver, S., Thoemmes, F., & Rosenthal (2014)  ####
#### Replicability and cumulative meta-analysis    ####
#### Perspectives on Psychological Science         ####
####                                               ####
#### Written by Felix Thoemmes, fjt36@cornell.edu  ####
#### Visit                                         ####
#### www.human.cornell.edu/hd/qml/software.cfm     ####
#### for updates                                   ####
#### Version 1.0                                   ####
#### 2/28/2014                                     ####
#######################################################

#######################################################
### Note: All computations are performed by the    ####
### meta package (Schwarzer, 2013)                 ####
### citation information is given below            ####
#######################################################

#Load required package "meta"
install.packages("meta")
library(meta)

#citation information for the meta package
citation("meta")

## Guido Schwarzer (2013). meta: Meta-Analysis with R. R package version 3.1-2.
## http://CRAN.R-project.org/package=meta


#Input data into a dataframe - here done by hand, but 
#alternatively, one could also read in an Excel spreadsheet

#The data must be arranged in the following order
#sample size experimental group, mean experimental group,
#standard deviation experimental group, sample size control
#group, mean control group, standard deviation control
#group

#The code below shows two studies being inputted
#If more than two studies are entered, simply append the
#information (sample size etc.) using comma-separated
#values in each of the c() brackets below

data1 <- data.frame(n.e=c(25,25), mean.e=c(0,0), sd.e=c(1.03,1.07), 
                    n.c=c(25,25), mean.c=c(.64,.40), sd.c=c(1.03,1.07))

#this performs a regular meta analysis
#no output is generated at this time
meta1 <- metacont(n.e, mean.e, sd.e, n.c, mean.c, sd.c,   data=data1, sm="SMD")

#this outputs relevant information about the meta-analysis,
#including pooled effect sizes and heterogeneity indices
#note that meta uses Hedges' g (small-sample corrected Cohen's d) by default
meta1

#this performs a CCMA, using the fixed effects estimator
metacum(meta1,pooled="fixed")

#if random-effects estimator is desired, replace the word fixed with random
metacum(meta1,pooled="random")

#this provides a forest plot of the CCMA under either fixed or random effects model
forest(metacum(meta1,pooled="fixed"))
forest(metacum(meta1,pooled="random"))
